`dread_depackager` created by *stuckpixel*, forked from `exlaunch` by *shadowninja108*. Licensed GPL v2.0 or later. 

More details: https://github.com/pixel-stuck/exlaunch/blob/main/LICENSE

---

This is a build with [Remote Lua support](https://github.com/randovania/exlaunch), with version 
[Remote Lua v1](https://github.com/randovania/exlaunch/releases/tag/remote-lua-v1).
